{
 "metadata": {
  "name": ""
 },
 "nbformat": 3,
 "nbformat_minor": 0,
 "worksheets": [
  {
   "cells": [
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "# The Basal Ganglia\n",
      "\n",
      "The basal ganglia\n",
      "according to [Stewart 2010](http://compneuro.uwaterloo.ca/files/publications/stewart.2010.pdf)\n",
      "is an action selector\n",
      "that chooses whatever action has the best \"salience\" or \"goodness\".\n",
      "Its really interesting behaviour manifests itself\n",
      "when it interacts with the thalamus and other components of the brain,\n",
      "but in this example we will only show the basal ganglia's basic behaviour.\n",
      "It will choose between three actions\n",
      "that we'll pretend are \"eating\", \"sleeping\" and \"playing\"."
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "import numpy as np\n",
      "import matplotlib.pyplot as plt\n",
      "%matplotlib inline\n",
      "\n",
      "import nengo\n",
      "%load_ext nengo.ipynb"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "display_data",
       "text": [
        "<IPython.core.display.Javascript at 0x7f69e85a5650>"
       ]
      }
     ],
     "prompt_number": 1
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "## Step 1: Create the Network\n",
      "Here we create the basal ganglia and the action input node."
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "model = nengo.Network(label='Basal Ganglia')\n",
      "with model:\n",
      "    basal_ganglia = nengo.networks.BasalGanglia(dimensions=3)\n",
      "\n",
      "class ActionIterator(object):\n",
      "    def __init__(self, dimensions):\n",
      "        self.actions = np.ones(dimensions) * 0.1\n",
      "        \n",
      "    def step(self, t):\n",
      "        # one action at time dominates\n",
      "        dominate = int(t % 3)\n",
      "        self.actions[:] = 0.1\n",
      "        self.actions[dominate] = 0.8\n",
      "        return self.actions\n",
      "\n",
      "action_iterator = ActionIterator(dimensions=3)\n",
      "\n",
      "with model:\n",
      "    actions = nengo.Node(action_iterator.step, label=\"actions\")"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [],
     "prompt_number": 2
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "## Step 2: Connect the Network\n",
      "Connect the input to the basal ganglia and connect the probes"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "with model:\n",
      "    nengo.Connection(actions, basal_ganglia.input, synapse=None)\n",
      "    selected_action = nengo.Probe(basal_ganglia.output, synapse=0.01)\n",
      "    input_actions = nengo.Probe(actions, synapse=0.01)"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [],
     "prompt_number": 3
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "## Step 3: Simulate the Network and Plot the Results"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "with nengo.Simulator(model) as sim:\n",
      "    # This will take a while\n",
      "    sim.run(6)"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [],
     "prompt_number": 4
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "plt.subplot(2, 1, 1)\n",
      "plt.plot(sim.trange(), sim.data[input_actions].argmax(axis=1))\n",
      "plt.ylim(-0.1, 2.1)\n",
      "plt.xlabel('time [s]')\n",
      "plt.title(\"Index of actual max value\")\n",
      "plt.subplot(2, 1, 2)\n",
      "plt.plot(sim.trange(), sim.data[selected_action].argmax(axis=1))\n",
      "plt.ylim(-0.1, 2.1)\n",
      "plt.xlabel('time [s]')\n",
      "plt.title(\"Basal ganglia selected max value\")\n",
      "plt.tight_layout()"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAAagAAAEbCAYAAACP7BAbAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nwOlGAAAAAElFTkSuQmCC\n",
       "text": [
        "<matplotlib.figure.Figure at 0x7f69a76fc650>"
       ]
      }
     ],
     "prompt_number": 5
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "As expected, the maximum index\n",
      "is found at 0, then 1, then 2\n",
      "or \"eating\", \"sleeping\", then \"playing\".\n",
      "Note that if you zoom in enough on the basal ganglia values,\n",
      "you'll be able to see a bit of a delay between finding max values.\n",
      "If you read the aforementioned paper,\n",
      "you'll see that this is expected and matches previous experiments."
     ]
    }
   ],
   "metadata": {}
  }
 ]
}